SERVICE = "00001523-1212-efde-1523-785feabcd124"
PWR_CHARACTERISTIC = "00001525-1212-EFDE-1523-785FEABCD124"
IDENTIFY_CHARACTERISTIC = "00008421-1212-EFDE-1523-785FEABCD124"
PWR_ON = b"\x01"
PWR_STANDBY = b"\x00"
NAME_SUFFIX = "LHB-"